pub struct Vera { /* private fields */ }Expand description
The struct the user interacts with.
Implementations
Sourceimpl Vera
impl Vera
Sourcepub fn reset(&mut self, input: Input)
pub fn reset(&mut self, input: Input)
Resets vertex and uniform data from input, which is consumed.
In heavy animations, resetting is useful for reducing the CPU/GPU usage if you split you animations in several parts. Also useful if called from a loop for hot-reloading.
Sourcepub fn show(&mut self) -> bool
pub fn show(&mut self) -> bool
Shows the animation form start to end once.
- Panics if there was an unexpected exit code from the event loop
- Returns
falseif the window was closed while showing. - Returns true otherwise.
pub fn save(&mut self, width: u32, height: u32)